# mra-tools
MRA Mapping Scripts and QA Tools


## How to use notebooks

Notebooks are best installed in a python3 virtualenv. 

```
$ virtualenv arcgis-dev
$ source arcgis-dev/bin/activate
(arcgis-dev) $ pip install -r pip-requirements.dev.txt
... INSTALLS REQUIREMENTS
(arcgis-dev) $ jupyter notebook
```

Jupyter will display a URL or file link that will enable you to work on the notebook on your local computer



